@@ -6,6 +6,7 @@ sequences, and displays some properties of the transformer model.
 """
 import math
 import os
+import time
 from copy import deepcopy
 from os.path import join
 from pathlib import Path
@@ -86,6 +87,7 @@ class TransformersWrapper:
         if self._multi_gpus:
             # kill worker to free RAM
             _ = [ray.kill(worker) for worker in self._workers]
+            time.sleep(1)  # 1 sec timer to be sure ray workers are killed
             self._ray_cls = None
             self._workers = None
 
@@ -438,6 +440,7 @@ class TransformersWrapper:
         tokens_list: List[str] = None,
         pass_mode: str = "forward",
         silent: bool = False,
+        normalize: bool = True,
     ) -> List[float]:
         """Function that computes loglikelihoods of sequences.
         It returns a list of float values.
@@ -448,6 +451,9 @@ class TransformersWrapper:
         we remove them and compute probabilities only over the 20 natural amino-acids.
         This behavior can be overridden through the tokens_list argument that enable
         the user to choose the tokens to consider when computing probabilities.
+        By default, all loglikelihoods are normalized by the sequence length. For
+        example, a loglikelihood of -0.35 means that every amino acids are predicted with
+        a probability of 0.7 in average.
 
         Args:
             sequences: List of sequences
@@ -455,10 +461,20 @@ class TransformersWrapper:
             tokens_list: List of tokens to consider
             pass_mode: Mode of model evaluation ('forward' or 'masked')
             silent : display or not progress bar
-
+            normalize : If True, loglikelihood are normalize by sequence length.
         Returns:
             List[float]: list of log-likelihoods, one per sequence
         """
+        tokens_list = NATURAL_AAS_LIST if tokens_list is None else tokens_list
+        sequences, lengths = init_model_sequences(
+            sequences=sequences,
+            model_dir=self._model_dir,
+            model_is_msa=self._language_model.is_msa,
+            n_seqs_msa=0,
+            vocab_size=self._language_model.vocab_size,
+            pass_mode=pass_mode,
+            tokens_list=tokens_list,
+        )
         self.init_ray_workers()
         if self._language_model.is_msa:
             raise NotImplementedError(
@@ -474,6 +490,8 @@ class TransformersWrapper:
                 [np.log(probabilities_dict[i][sequence[i]]) for i in range(len(sequence))]  # type: ignore
             )
             log_likelihoods.append(float(log_likelihood))
+        if normalize:
+            log_likelihoods = [log / length for log, length in zip(log_likelihoods, lengths)]
 
         self.delete_ray_workers()
         return log_likelihoods
